@@ -18,21 +18,20 @@ extern "C"
 
 struct parserutils_buffer
 {
+	uint8_t *alloc;
 	uint8_t *data;
 	size_t length;
 	size_t allocated;
-
-	parserutils_alloc alloc;
-	void *pw;
 };
 typedef struct parserutils_buffer parserutils_buffer;
 
-parserutils_error parserutils_buffer_create(parserutils_alloc alloc, 
-		void *pw, parserutils_buffer **buffer);
+parserutils_error parserutils_buffer_create(parserutils_buffer **buffer);
 parserutils_error parserutils_buffer_destroy(parserutils_buffer *buffer);
 
 parserutils_error parserutils_buffer_append(parserutils_buffer *buffer, 
 		const uint8_t *data, size_t len);
+parserutils_error parserutils_buffer_appendv(parserutils_buffer *buffer,
+		size_t count, ...);
 parserutils_error parserutils_buffer_insert(parserutils_buffer *buffer, 
 		size_t offset, const uint8_t *data, size_t len);
 parserutils_error parserutils_buffer_discard(parserutils_buffer *buffer, 
